@@ -1,6 +1,8 @@
 import json
 import os
 from os.path import exists
+from time import time
+
 
 import yaml
 
@@ -25,12 +27,13 @@ class FileOperation:
         """
         save json file
         """
-        json_data = json.dumps(data)
-        file_to_write = path_file + '/results.json'
-        with open(file_to_write, 'w') as f:
+        FileOperation.create_dir(path_file + "/json_results/")
+        file_to_write = (
+            path_file + f"/json_results/{str(int(time() * 1000))}_results.json"
+        )
+        with open(file_to_write, "w") as f:
             json.dump(data, f)
 
-
     @staticmethod
     def load_yaml(path_to_file: str) -> dict:
         with open(path_to_file, "r") as stream:
@@ -39,3 +42,8 @@ class FileOperation:
     @staticmethod
     def get_path_to_file(path: str, file_name: str) -> str:
         return os.path.join(path, file_name)
+
+    @staticmethod
+    def load_json(path):
+        with open(path) as handle:
+            return json.loads(handle.read())
